unit RUtil;
{
Copyright (C) 2016 - Ronald Daleske

Licence
=======

 LGPLv2.1 with static linking exception (See COPYING.modifiedLGPL.txt)

}

{$mode delphi} {Default to Delphi compatible syntax}
{$H+}          {Default to AnsiString}
{$inline on}   {Allow use of Inline procedures}


interface

uses
  GlobalConfig,
  GlobalConst,
  Classes,
  SysUtils,
  Console,
  ConsoleShell,
  Threads,
  RGraphics;


procedure Init_and_Clear_Screen;
procedure DrawBitmap_to_Framebuffer(POS_X, POS_Y : LongWord; BMP_Name : String);
procedure Framebuffer_to_Bitmap(X,Y,Width,Height : LongWord; BMP_Name : String);
procedure ScreenShot_to_Bitmap(BMP_Name : String);
procedure ScreenShot;

implementation


VAR
  ScreenShot_Counter : LongWord;



{==============================================================================}
{==============================================================================}
{}
procedure Init_and_Clear_Screen;
begin

  CONSOLE_SHELL_ENABLED:=True;
  CONSOLE_SHELL_POSITION:=CONSOLE_POSITION_FULL;
  ConsoleShellDeviceAdd(ConsoleDeviceGetDefault);

  FramebufferConsoleClear(ConsoleDeviceGetDefault,COLOR_WHITE);

end; { procedure Init_and_Clear_Screen }





{==============================================================================}
{==============================================================================}
{}
procedure DrawBitmap_to_Framebuffer(POS_X, POS_Y : LongWord; BMP_Name : String);
var
  D_Bitmap : TBitmap;
begin

  D_Bitmap := TBitmap.Create;
  D_Bitmap.LoadFromFile(BMP_Name);

  FramebufferConsoleDrawStream(ConsoleDeviceGetDefault,POS_X,POS_Y,
                               D_Bitmap.Width,D_Bitmap.Height,
                               D_Bitmap.BM_RAW_Memory);

  D_Bitmap.Free;

end; { procedure DrawBitmap_to_Framebuffer }






{==============================================================================}
{==============================================================================}
{}
procedure Framebuffer_to_Bitmap(X,Y,Width,Height : LongWord; BMP_Name : String);
var
  D_Bitmap : TBitmap;
begin

  D_Bitmap := TBitmap.Create;

  D_Bitmap.Width:=Width;
  D_Bitmap.Height:=Height;

  FramebufferConsoleGetStream(ConsoleDeviceGetDefault,X,Y,
                              D_Bitmap.Width,D_Bitmap.Height,
                              D_Bitmap.BM_RAW_Memory);

  D_Bitmap.SaveToFile(BMP_Name);

  D_Bitmap.Free;

end; { procedure Framebuffer_to_Bitmap }



{==============================================================================}
{==============================================================================}
{}
procedure ScreenShot_to_Bitmap(BMP_Name : String);
var
  D_Bitmap : TBitmap;
begin

  D_Bitmap := TBitmap.Create;

  D_Bitmap.Width:=1280;
  D_Bitmap.Height:=1024;

  FramebufferConsoleGetStream(ConsoleDeviceGetDefault,0,0,
                              D_Bitmap.Width,D_Bitmap.Height,
                              D_Bitmap.BM_RAW_Memory);

  D_Bitmap.SaveToFile(BMP_Name);

  D_Bitmap.Free;

end; { procedure ScreenShot_to_Bitmap }



{==============================================================================}
{==============================================================================}
{}
procedure ScreenShot;
var
  name : String;
begin

  INC(ScreenShot_Counter);
  name:='C:\ScreenShot_'+IntToStr(ScreenShot_Counter)+'.BMP';
  ScreenShot_to_Bitmap(name);

end; { procedure ScreenShot }


{==============================================================================}
{==============================================================================}

initialization
 ScreenShot_Counter:=0;

{==============================================================================}

finalization
 {Nothing}

{==============================================================================}
{==============================================================================}



end.

